local ext = require "shellExtension" 
assert(shellExtension)

-- Altera o título da janela de execução.
ext.setWinTitle("zip")

local porExt, errorMsg = ext.getParameterValue(arg, 'POREXT') 
assert(errorMsg == nil, errorMsg)

local output, errorMsg = ext.getParameterValue(arg, 'SAIDA') 
assert(errorMsg == nil, errorMsg)

local commonInPath
local filesIn, fileTable

if porExt == "NAO" then
  local input, errorMsg = ext.getParameterValue(arg, 'ENTRADA') 
  assert(errorMsg == nil, errorMsg)

  local inputTable = ext.toStringArray(input)
  commonInPath, fileTable  = ext.getCommonPath(inputTable)
  assert(commonInPath, 
    "Nao foi possivel obter o caminho comum a todos os arquivos")
else
  local extension, errorMsg = ext.getParameterValue(arg, 'EXT') 
  assert(errorMsg == nil, errorMsg)

  local diretorio, errorMsg = ext.getParameterValue(arg, 'DIRETORIO') 
  assert(errorMsg == nil, errorMsg)

  commonInPath = diretorio
  filesIn = "\\\*"..extension
end

-- obtem o path da saida com relacao ao path comun
local outputRelPath = ext.findRelativePath(commonInPath, output)
assert(outputRelPath, "Falha na obtencao do caminho relativo")

--remove o zip se ele existir e em seguida, cria um vazio
ext.fileRemove(output)
local outFile = ext.fileOpen(output, "w")
outFile:close()

-- Vai para o diretorio comum
ext.chdir(commonInPath)

if porExt == "NAO" then
  -- Cria arquivos temporários (um para os arquivos e outro para os diretórios)
  -- com as entradas do zip, pois podem ser passados muitos arquivos como entrada
  -- e estourar o limite da linha de comando.
  --local tmpFileName = mktemp()
  --local tmpDirName = mktemp()
  local tmpFileName = outputRelPath..".tmpfile"
  local tmpDirName = outputRelPath..".tmpdir"
  local tmpFileHandle, err = ext.fileOpen(tmpFileName, "w")
  local tmpDirHandle, err = ext.fileOpen(tmpDirName, "w")
  local flagFile, flagDir = false, false
  for i=1, #fileTable do
    if ext.isDir(fileTable[i]) then
      tmpDirHandle:write(fileTable[i].."\n") 
      flagDir = true
    else
      tmpFileHandle:write(fileTable[i].."\n") 
--    tmpFileHandle:write(fileTable[i]..".csbase\n")
--    tmpFileHandle:write(fileTable[i]..".csbase_description\n")
      flagFile = true
    end
  end
  tmpDirHandle:close()
  tmpFileHandle:close()
  
  ext.setWinTitle("zip - "..output)
  if flagDir then
    assert(ext.execCmdLine(ext.SHELL_BASH, "wzzip -rP", nil, true, outputRelPath, 
      "@"..tmpDirName), "Falha na execucao do comando")
  end
  
  if flagFile then
    assert(ext.execCmdLine(ext.SHELL_BASH, "wzzip -P", nil, true, outputRelPath, 
      "@"..tmpFileName), "Falha na execucao do comando")
  end
  
  ext.fileRemove(tmpFileName)
  ext.fileRemove(tmpDirName)
else
  ext.setWinTitle("zip - "..output)
  assert(ext.execCmdLine(ext.SHELL_BASH, "wzzip -rP", nil, true, outputRelPath, 
      filesIn), "Falha na execucao do comando")
end
